<TS version="2.1" language="no">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Høyreklikk for å redigere adresse eller etikett</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Opprett en ny adresse</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Ny</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopier</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">C&amp;Tap</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Slett den valgte adressen fra listen </translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Tast inn adressen eller etiketten for å søke</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Eksporter dataene i den nåværende fanen til en fil</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Eksporter</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Slett</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Velg adressen for å sende mynter til</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Velg adressen for å motta mynter på</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;Velg</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Dette er Bitcoin-adressene dine for å sende betalinger. Kontroller alltid beløpet og mottakeradressen før du sender mynter.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Dette er Bitcoin-adressene dine for å motta betalinger. Bruk knappen ‘Opprett ny mottaksadresse’ i mottaksfanen for å opprette nye adresser.Signering er kun mulig med adresser av typen ‘legacy’.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Kopier adresse</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Kopier &amp;etikett</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Rediger</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Eksporter adresseliste</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Kommaseparert fil</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Det oppstod en feil under forsøk på å lagre adresselisten til %1. Vennligst prøv igjen.</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">Sender adresser - %1</translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">Mottaksadresser - %1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Eksportering mislyktes</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etikett</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Adresse</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(ingen etikett)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Passord-dialog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Skriv inn passord</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Nytt passord</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Gjenta nytt passord</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Vis passord</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Krypter lommebok</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Denne operasjonen krever passordet til lommeboken for å låse opp lommeboken.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Lås opp lommebok</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Endre passord</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Bekreft kryptering av lommebok</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Advarsel: Hvis du krypterer lommeboken din og mister passordet, vil du 1 MISTE ALLE BITCOINENE DINE 1 !</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Er du sikker på at du vil kryptere lommeboken din?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Lommebok kryptert</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Skriv inn det nye passordet for lommeboken. 1 Vennligst bruk et passord med 2 ti eller flere tilfeldige tegn 2, eller 3 åtte eller flere ord 3.</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Skriv inn det gamle passordet og det nye passordet for lommeboken.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Fortsett</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished">Tilbake</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Husk at kryptering av lommeboken din ikke fullt ut kan beskytte bitcoinene dine mot å bli stjålet av skadelig programvare som infiserer datamaskinen din.</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Lommebok skal krypteres</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Lommeboken din er i ferd med å bli kryptert.</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Lommeboken din er nå kryptert.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">VIKTIG: Eventuelle tidligere sikkerhetskopier du har laget av lommeboksfilen din bør erstattes med den nylig genererte, krypterte lommeboksfilen. Av sikkerhetsmessige årsaker vil tidligere sikkerhetskopier av den ukrypterte lommeboksfilen bli ubrukelige så snart du begynner å bruke den nye, krypterte lommeboken.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Kryptering av lommebok mislyktes</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Kryptering av lommebok mislyktes på grunn av en intern feil. Lommeboken din ble ikke kryptert.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">De oppgitte passordene stemmer ikke overens.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Låsing av lommebok mislyktes</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Passordet som ble skrevet inn for dekryptering av lommeboken var feil.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">Passordet som ble skrevet inn for dekryptering av lommeboken er feil. Det inneholder et nulltegn (dvs. en null byte). Hvis passordet ble satt med en versjon av denne programvaren før 25.0, prøv igjen med bare tegnene frem til – men ikke inkludert – det første nulltegnet. Hvis dette lykkes, vennligst sett et nytt passord for å unngå dette problemet i fremtiden.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Lommebokens passord ble endret vellykket.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">Endring av passord mislyktes</translation>
    </message>
    <message>
        <source>The old passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character.</source>
        <translation type="unfinished">Det gamle passordet som ble skrevet inn for dekryptering av lommeboken er feil. Det inneholder et nulltegn (dvs. en null byte). Hvis passordet ble satt med en versjon av denne programvaren før 25.0, prøv igjen med bare tegnene frem til – men ikke inkludert – det første nulltegnet.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Advarsel: Caps Lock-tasten er aktivert!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP-adresse/nettverksmaske</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Utestengt til</translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">Innstillingsfilen %1 kan være ødelagt eller ugyldig.</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">Ukontrollert unntak</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">En fatal feil oppstod. %1 kan ikke fortsette på en sikker måte og vil avslutte.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Intern feil</translation>
    </message>
    <message>
        <source>An internal error occurred. %1 will attempt to continue safely. This is an unexpected bug which can be reported as described below.</source>
        <translation type="unfinished">En intern feil oppstod. %1 vil forsøke å fortsette på en sikker måte. Dette er en uventet feil som kan rapporteres som beskrevet nedenfor.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Do you want to reset settings to default values, or to abort without making changes?</source>
        <extracomment>Explanatory text shown on startup when the settings file cannot be read. Prompts user to make a choice between resetting or aborting.</extracomment>
        <translation type="unfinished">Vil du tilbakestille innstillingene til standardverdier, eller avbryte uten å gjøre endringer?</translation>
    </message>
    <message>
        <source>A fatal error occurred. Check that settings file is writable, or try running with -nosettings.</source>
        <extracomment>Explanatory text shown on startup when the settings file could not be written. Prompts user to check that we have the ability to write to the file. Explains that the user has the option of running without a settings file.</extracomment>
        <translation type="unfinished">En fatal feil oppstod. Kontroller at innstillingsfilen er skrivbar, eller prøv å kjøre med -nosettings.</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Feil: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 avsluttet ennå ikke trygt…</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Beløp</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">standard lommebok</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Oversikt</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Vis generell oversikt over lommeboken</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Transaksjoner</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Bla gjennom transaksjonshistorikk</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">A&amp;vslutt</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Avslutt programmet</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">&amp;Om %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">Vis informasjon om %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Om &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Vis informasjon om Qt</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">Endre konfigurasjonsalternativer for %1</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Opprett en ny lommebok</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Minimer</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Lommebok:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Nettverksaktivitet deaktivert.</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">Proxy er aktivert: %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Send mynter til en Bitcoin-adresse</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Sikkerhetskopier lommeboken til et annet sted</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Endre passordet som brukes for kryptering av lommeboken</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Mottak</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Alternativer…</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Krypter Lommebok…</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Krypter de private nøklene som tilhører lommeboken din</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">&amp;Sikkerhetskopier Lommebok…</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;Endre Passord…</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">Signer &amp;melding…</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Signer meldinger med Bitcoin-adressene dine for å bevise at du eier dem</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">&amp;Verifiser melding…</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Verifiser meldinger for å sikre at de ble signert med de spesifiserte Bitcoin-adressene</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">&amp;Last inn PSBT fra fil…</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">Åpne &amp;URI…</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Lukk Lommebok…</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Opprett Lommebok…</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Lukk Alle Lommebøker…</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Fil</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Innstillinger</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Hjelp</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Faner verktøylinje</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">Synkroniserer overskrifter (%1%)…</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Synkroniserer med nettverket…</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">Indekserer blokker på disk…</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">Behandler blokker på disk…</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Kobler til jevnaldrende…</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Be om betalinger (genererer QR-koder og bitcoin: URIs)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Vis listen over brukte sendeadresser og etiketter</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Vis listen over brukte mottaksadresser og etiketter</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Kommandolinjealternativer</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform>Behandlet %n blokk(er) med transaksjonshistorikk.</numerusform>
            <numerusform>Behandlet %n blokk(er) med transaksjonshistorikk.</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 etter</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">Tar igjen…</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Siste mottatte blokk ble generert for %1 siden.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Transaksjoner etter dette vil ennå ikke være synlige.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Feil</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Advarsel</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Informasjon</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Oppdatert</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">Last inn delvis signert Bitcoin-transaksjon</translation>
    </message>
    <message>
        <source>Load PSBT from &amp;clipboard…</source>
        <translation type="unfinished">Last inn PSBT fra &amp;utklippstavle…</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">Last inn delvis signert Bitcoin-transaksjon fra utklippstavlen</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Node-vindu</translation>
    </message>
    <message>
        <source>Open node debugging and diagnostic console</source>
        <translation type="unfinished">Åpne node-feilsøkings- og diagnostikkonsoll</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">Åpne node-feilsøkings- og diagnostikkonsoll</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Mottaksadresser</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">Åpne en bitcoin: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Åpne Lommebok</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Åpne en lommebok</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Lukk lommebok</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">Gjenopprett Lommebok…</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">Gjenopprett en lommebok fra en sikkerhetskopifil</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Lukk alle lommebøker</translation>
    </message>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">Migrer Lommebok</translation>
    </message>
    <message>
        <source>Migrate a wallet</source>
        <translation type="unfinished">Migrer en lommebok</translation>
    </message>
    <message>
        <source>Show the %1 help message to get a list with possible Bitcoin command-line options</source>
        <translation type="unfinished">Vis %1 hjelpetekst for å få en liste over mulige Bitcoin kommandolinjealternativer</translation>
    </message>
    <message>
        <source>&amp;Mask values</source>
        <translation type="unfinished">&amp;Masker verdier</translation>
    </message>
    <message>
        <source>Mask the values in the Overview tab</source>
        <translation type="unfinished">Masker verdiene i Oversikt-fanen</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Ingen lommebøker tilgjengelig</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Lommebokdata</translation>
    </message>
    <message>
        <source>Load Wallet Backup</source>
        <extracomment>The title for Restore Wallet File Windows</extracomment>
        <translation type="unfinished">Last inn sikkerhetskopi av lommebok</translation>
    </message>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of pop-up window shown when the user is attempting to restore a wallet.</extracomment>
        <translation type="unfinished">Gjenopprett lommebok</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Lommeboknavn</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Vindu 
</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Hovedvindu</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 klient</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;Skjul</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">V&amp;is</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform>%n aktive tilkoblinger til Bitcoin-nettverket.</numerusform>
            <numerusform>1%n aktive tilkoblinger til Bitcoin-nettverket.</numerusform>
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Klikk for flere handlinger.</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">Vis Peer fanen</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Deaktiver nettverksaktivitet</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">Aktiver nettverksaktivitet</translation>
    </message>
    <message>
        <source>Pre-syncing Headers (%1%)…</source>
        <translation type="unfinished">Forhåndssynkroniserer overskrifter (%1%)…</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Feil: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Advarsel: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Dato: %1</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Beløp: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Lommebok: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Etikett: %1 
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Adresse: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Sendt transaksjon</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Innkommende transaksjon</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation type="unfinished">HD-nøkkelgenerering er aktivert</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">HD nøkkelgenerering er deaktivert</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Privat nøkkel er deaktivert</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Lommeboken er kryptert og for øyeblikket låst opp</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Lommeboken er &lt;b&gt;kryptert&lt;/b&gt; og for øyeblikket &lt;b&gt;låst&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">Opprinnelig melding:</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    <message>
        <source>Unit to show amounts in. Click to select another unit.</source>
        <translation type="unfinished">Enhet for å vise beløp. Klikk for å velge en annen enhet.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">Myntvalg</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Mengde:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Byte:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Beløp:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Gebyr</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Etter gebyr</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Veksel</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">(av)velg alle</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Trevisning</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Listevisning</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Beløp</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Mottatt med etikett</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Mottatt med adresse</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dato</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Bekreftelser</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Bekreftet</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Kopier beløp</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">Kopier adresse</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Kopier &amp;etikett</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Kopier &amp;beløp</translation>
    </message>
    <message>
        <source>Copy transaction &amp;ID and output index</source>
        <translation type="unfinished">Kopier transaksjons-&amp;ID og outputindeks</translation>
    </message>
    <message>
        <source>L&amp;ock unspent</source>
        <translation type="unfinished">L&amp;ås ubrukte</translation>
    </message>
    <message>
        <source>&amp;Unlock unspent</source>
        <translation type="unfinished">&amp;Lås opp ubrukte</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Kopier antall</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Kopier gebyr</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Kopier etter gebyr</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Kopier byte</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Kopier endring</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(ingen etikett)</translation>
    </message>
    </context>
<context>
    <name>MigrateWalletActivity</name>
    <message>
        <source>Migrate Wallet</source>
        <translation type="unfinished">Migrer Lommebok</translation>
    </message>
    </context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Åpne Lommebok</translation>
    </message>
    </context>
<context>
    <name>RestoreWalletActivity</name>
    <message>
        <source>Restore Wallet</source>
        <extracomment>Title of progress window which is displayed when wallets are being restored.</extracomment>
        <translation type="unfinished">Gjenopprett lommebok</translation>
    </message>
    </context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Lukk lommebok</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Lukk alle lommebøker</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Lommeboknavn</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Feil</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Vindu 
</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Fortsett</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Feil</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Adresse </translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Node-vindu</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">Kopier adresse</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">Kopier adresse</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Kopier &amp;etikett</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Kopier &amp;beløp</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Beløp:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Lommebok:</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dato</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etikett</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(ingen etikett)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Mengde:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Byte:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Beløp:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Gebyr</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Etter gebyr</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Veksel</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Kopier antall</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Kopier beløp</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Kopier gebyr</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Kopier etter gebyr</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Kopier byte</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Kopier endring</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(ingen etikett)</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dato</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Beløp</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dato</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etikett</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(ingen etikett)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">Kopier adresse</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Kopier &amp;etikett</translation>
    </message>
    <message>
        <source>Copy &amp;amount</source>
        <translation type="unfinished">Kopier &amp;beløp</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Kommadelt fil</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Bekreftet</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Dato</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etikett</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Adresse</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Eksportering mislyktes</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Opprett en ny lommebok</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Feil</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Eksporter</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Eksporter dataene i den nåværende fanen til en fil</translation>
    </message>
    <message>
        <source>Wallet Data</source>
        <extracomment>Name of the wallet data file format.</extracomment>
        <translation type="unfinished">Lommebokdata</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">standard lommebok</translation>
    </message>
    </context>
</TS>